@@ -11,11 +11,11 @@ system names and date formats.
 The defaults are used in this module and across the Bright Edge eServices
 echo system.
 '''
-from .archiver import *
-from .msg import *
-from .script import *
+from .beearchiver import *
+from .beemsg import *
+from .beescript import *
 # from .strext import *
-from .tools import *
-from .venv import *
+from .beeutils import *
+from .beevenv import *
 
 _VERSION = '0.0.5'
